<?php


	// Prevent direct file access
	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}


	class CBXOnlineWidget extends WP_Widget {

		/**
		 *
		 * Unique identifier for your widget.
		 *
		 *
		 * The variable name is used as the text domain when internationalizing strings
		 * of text. Its value should match the Text Domain file header in the main
		 * widget file.
		 *
		 * @since    1.0.0
		 *
		 * @var      string
		 */
		protected $widget_slug = 'cbxuseronline'; //main parent plugin's language file

		/*--------------------------------------------------*/
		/* Constructor
		/*--------------------------------------------------*/

		/**
		 * Specifies the classname and description, instantiates the widget,
		 * loads localization files, and includes necessary stylesheets and JavaScript.
		 */
		public function __construct() {

			parent::__construct(
				$this->get_widget_slug(),
				esc_html__( 'CBX: Online Users', 'cbxuseronline' ),
				array(
					'classname'   => $this->get_widget_slug() . '-class',
					'description' => esc_html__( 'This widget shows online users based on widget setting', 'cbxuseronline' )
				)
			);


			// Refreshing the widget's cached output with each new post
			add_action( 'cbxuseronline_record', array( $this, 'flush_widget_cache' ) );

		} // end constructor


		/**
		 * Return the widget slug.
		 *
		 * @since    1.0.0
		 *
		 * @return    Plugin slug variable.
		 */
		public function get_widget_slug() {
			return $this->widget_slug;
		}

		/*--------------------------------------------------*/
		/* Widget API Functions
		/*--------------------------------------------------*/
		
		/**
		 * Outputs the content of the widget.
		 *
		 * @param array args  The array of form elements
		 * @param array instance The current instance of the widget
		 *
		 * @return int
		 */
		public function widget( $args, $instance ) {


			// Check if there is a cached output
			$cache = wp_cache_get( $this->get_widget_slug(), 'widget' );

			if ( ! is_array( $cache ) ) {
				$cache = array();
			}

			if ( ! isset ( $args['widget_id'] ) ) {
				$args['widget_id'] = $this->id;
			}

			if ( isset ( $cache[ $args['widget_id'] ] ) ) {
				return print $cache[ $args['widget_id'] ];
			}

			// go on with your widget logic, put everything into a string and …


			extract( $args, EXTR_SKIP );

			$widget_string = $before_widget;

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? esc_html__( 'Online Users', 'cbxuseronline' ) : $instance['title'], $instance, $this->id_base );
			// Defining the Widget Title
			if ( $title ) {
				$widget_string .= $args['before_title'] . $title . $args['after_title'];
			} else {
				$widget_string .= $args['before_title'] . $args['after_title'];
			}


			ob_start();


			$fields = array(
				'count'            => 1, //show user count
				'count_individual' => 1, //show individual count as per user type  member, guest and bot
				'member_count'     => 1, //show member user type count
				'guest_count'      => 1, //show guest user type count
				'bot_count'        => 1, //show bot user type count
				'page'             => 0, //show count for this page
				'mobile'           => 1, //show user mobile or desktop login information
				'memberlist'       => 1, //show member list
				'mostuseronline'   => 1, //most user online date and count
				'linkusername'     => 1  //link author page
			);

			foreach ( $fields as $field => $val ) {

				if ( isset( $instance[ $field ] ) ) {
					$instance[ $field ] = intval( $instance[ $field ] );
				} else {
					$instance[ $field ] = $val;
				}

			}


			$instance = apply_filters( 'cbxuseronline_widget_widget', $instance, $fields );


			$instance['page'] = ( $instance['page'] ) ? esc_url( $_SERVER['REQUEST_URI'] ) : '';
			$scope            = 'widget';


			echo CBXUseronlineHelper::cbxuseronline_display( $instance, $scope );


			$widget_string .= ob_get_clean();

			$widget_string .= $after_widget;


			$cache[ $args['widget_id'] ] = $widget_string;

			wp_cache_set( $this->get_widget_slug(), $cache, 'widget' );

			print $widget_string;

		} // end widget


		public function flush_widget_cache() {
			wp_cache_delete( $this->get_widget_slug(), 'widget' );
		}
		
		/**
		 * Processes the widget's options to be saved.
		 *
		 * @param array new_instance The new instance of values to be generated via the update.
		 * @param array old_instance The previous instance of values before the update.
		 *
		 * @return array|mixed|void
		 */
		public function update( $new_instance, $old_instance ) {

			$instance = $old_instance;

			$fields = array(
				'count'            => 1, //show user count
				'count_individual' => 1, //show individual count as per user type  member, guest and bot
				'member_count'     => 1, //show member user type count
				'guest_count'      => 1, //show guest user type count
				'bot_count'        => 1, //show bot user type count
				'page'             => 0, //show count for this page
				'mobile'           => 1, //show user mobile or desktop login information
				'memberlist'       => 1, //show member list
				'mostuseronline'   => 1, //most user online date and count
				'linkusername'     => 1  //link author page
			);

			$instance['title'] = esc_attr( $new_instance['title'] );


			foreach ( $fields as $field => $val ) {
				if ( isset( $new_instance[ $field ] ) ) {
					$instance[ $field ] = 1; //either te
				} else {
					$instance[ $field ] = 0;
				}

			}

			$instance = apply_filters( 'cbxuseronline_widget_update', $instance, $new_instance );


			return $instance;

		} // end widget

		/**
		 * Generates the administration form for the widget.
		 *
		 * @param array instance The array of keys and values for the widget.
		 */
		public function form( $instance ) {

			$fields = array(
				'title'            => esc_html__( 'Online Users', 'cbxuseronline' ),
				'count'            => 1, //show user count
				'count_individual' => 1, //show individual count as per user type  member, guest and bot
				'member_count'     => 1, //show member user type count
				'guest_count'      => 1, //show guest user type count
				'bot_count'        => 1, //show bot user type count
				'page'             => 0, //show count for this page
				'mobile'           => 1, //show user mobile or desktop login information
				'memberlist'       => 1, //show member list
				'mostuseronline'   => 1, //most user online date and count
				'linkusername'     => 1  //link author page
			);

			$fields = apply_filters( 'cbxuseronline_widget_form_fields', $fields );

			$instance = wp_parse_args(
				(array) $instance,
				$fields
			);

			//$instance = apply_filters('cbxuseronline_widget_form', $instance, $fields);

			extract( $instance, EXTR_SKIP );


			/*
			$title               = esc_attr( $instance['title'] );
			$count               = !empty($instance['count']) ? intval( $instance['count'] )  : 1;
			$count_individual    = isset($instance['count_individual'])     ? intval( $instance['count_individual'] )  : 1;
			$member_count        = isset($instance['member_count'])         ? esc_attr( $instance['member_count'] ): 1;
			$guest_count         = isset($instance['guest_count'])        ? esc_attr( $instance['guest_count'] ) : 1;
			$bot_count           = isset($instance['bot_count'])     ? esc_attr( $instance['bot_count'] ): 1;
			$page                = isset($instance['page'])        ? intval( $instance['page'] ): 1;
			$mobile              = isset($instance['mobile'])        ? intval( $instance['mobile'] ): 1;
			*/

			// Display the admin form
			include( plugin_dir_path( __FILE__ ) . 'views/admin.php' );

		} // end form
	} // end class