<?php
	
	namespace CBXOnlineElementorWidget\Widgets;
	
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}
	
	/**
	 * CBX Latest Tweets Elementor Widget
	 */
	class CBXOnlineElementorWidget extends \Elementor\Widget_Base {
		
		/**
		 * Retrieve Online User widget name.
		 *
		 * @since  1.0.9
		 * @access public
		 *
		 * @return string Widget name.
		 */
		public function get_name() {
			return 'cbx_online_user';
		}
		
		/**
		 * Retrieve Online User widget title.
		 *
		 * @since  1.0.9
		 * @access public
		 *
		 * @return string Widget title.
		 */
		public function get_title() {
			return esc_html__( 'Online user', 'cbxuseronline' );
		}
		
		/**
		 * Get widget icon.
		 *
		 * Retrieve heading widget icon.
		 *
		 * @since 1.0.9
		 * @access public
		 *
		 * @return string Widget icon.
		 */
		public function get_icon() {
			return 'cbxonlineuser-icon';
		}
		
		/**
		 * Get widget categories.
		 *
		 * Retrieve the widget categories.
		 *
		 * @since  1.0.9
		 * @access public
		 *
		 * @return array Widget categories.
		 */
		public function get_categories() {
			return array( 'codeboxr' );
		}
		
		
		/**
		 * Register Online User widget controls.
		 *
		 * Adds different input fields to allow the user to change and customize the widget settings.
		 *
		 * @since  1.0.9
		 * @access protected
		 */
		protected function _register_controls() {
			
			
			$this->start_controls_section(
				'section_cbxuseronline',
				array(
					'label' => esc_html__( 'CBX Online User ', 'cbxuseronline' ),
				)
			);
			
			$this->add_control(
				'cbxuseronline_memberlist',
				array(
					'label'        => __( 'Show Memberlist', 'plugin-domain' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_linkusername',
				array(
					'label'        => __( 'Link user to author page', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_count',
				array(
					'label'        => __( 'Show online count', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_count_individual',
				array(
					'label'        => __( 'Show individual count', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_member_count',
				array(
					'label'        => __( 'Show member count', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_guest_count',
				array(
					'label'        => __( 'Show guest count', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_bot_count',
				array(
					'label'        => __( 'Show bot count', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_page',
				array(
					'label'        => __( 'Show for current page', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_mostuseronline',
				array(
					'label'        => __( 'Show most user online', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			$this->add_control(
				'cbxuseronline_mobile',
				array(
					'label'        => __( 'Show mobile or desktop logged in status', 'cbxuseronline' ),
					'type'         => \Elementor\Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'cbxuseronline' ),
					'label_off'    => __( 'Hide', 'cbxuseronline' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				)
			);
			
			
			$this->end_controls_section();
		}
		
		/**
		 * @param int $value
		 *
		 * @return int
		 */
		private function yes_no_to_10( $value = 0 ) {
			if ( $value === 'yes' ) {
				return 1;
			}
			
			return 0;
		}
		
		/**
		 * Render oEmbed widget output on the frontend.
		 *
		 * Written in PHP and used to generate the final HTML.
		 *
		 * @since 1.0.9
		 * @access protected
		 */
		protected function render() {
			
			$settings = $this->get_settings();
			
			
			//render online user from custom attributes
			$memberlist = isset( $settings['cbxuseronline_memberlist'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_memberlist'] ) : 0;
			
			
			$linkusername     = isset( $settings['cbxuseronline_linkusername'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_linkusername'] ) : 0;
			$count            = isset( $settings['cbxuseronline_count'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_count'] ) : 0;
			$count_individual = isset( $settings['cbxuseronline_count_individual'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_count_individual'] ) : 0;
			$member_count     = isset( $settings['cbxuseronline_member_count'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_member_count'] ) : 0;
			$guest_count      = isset( $settings['cbxuseronline_guest_count'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_guest_count'] ) : 0;
			$bot_count        = isset( $settings['cbxuseronline_bot_count'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_bot_count'] ) : 0;
			$page             = isset( $settings['cbxuseronline_page'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_page'] ) : 0;
			$mostuseronline   = isset( $settings['cbxuseronline_mostuseronline'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_mostuseronline'] ) : 0;
			$mobile           = isset( $settings['cbxuseronline_mobile'] ) ? $this->yes_no_to_10( $settings['cbxuseronline_mobile'] ) : 0;
			
			
			echo do_shortcode( '[cbxuseronline memberlist="' . $memberlist . '" linkusername="' . $linkusername . '" count="' . $count . '" count_individual="' . $count_individual . '" member_count="' . $member_count . '" guest_count="' . $guest_count . '" bot_count="' . $bot_count . '" page="' . $page . '" mostuseronline="' . $mostuseronline . '"mobile="' . $mobile . '"]' );
			
			
		}//end method render
		
		protected function _content_template() {
		}//end method _content_template
		
		
	}//end class CBXOnlineElementorWidget